===============================
Boundary and initial conditions
===============================

Sub-commands to support the boundary and initial conditions components

Boundary
~~~~~~~~

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.boundary.SIDE
    rompy_swan.subcomponents.boundary.SEGMENT
    rompy_swan.subcomponents.boundary.PAR
    rompy_swan.subcomponents.boundary.CONSTANTPAR
    rompy_swan.subcomponents.boundary.VARIABLEPAR
    rompy_swan.subcomponents.boundary.CONSTANTFILE
    rompy_swan.subcomponents.boundary.VARIABLEFILE

Initial conditions
~~~~~~~~~~~~~~~~~~

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.boundary.DEFAULT
    rompy_swan.subcomponents.boundary.ZERO
    rompy_swan.subcomponents.boundary.HOTSINGLE
    rompy_swan.subcomponents.boundary.HOTMULTIPLE
